==> hive-apache-3.0.0-4-sources.jar: org/apache/hadoop/hive/ql/exec/tez/AmPluginNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.tez;

import org.apache.hadoop.security.token.Token;
import org.apache.hive.common.util.Ref;
import org.apache.tez.common.security.JobTokenIdentifier;
import io.prestosql.hive.$internal.org.codehaus.jackson.annotate.JsonIgnore;
import io.prestosql.hive.$internal.org.codehaus.jackson.annotate.JsonProperty;
import io.prestosql.hive.$internal.org.codehaus.jackson.map.annotate.JsonSerialize;

@JsonSerialize
public interface AmPluginNode {
  class AmPluginInfo {
    @JsonProperty("amPluginPort")
    public final int amPluginPort;
    public final Token<JobTokenIdentifier> amPluginToken;
    public final String amPluginTokenJobId;
    @JsonProperty("amHost")
    public final String amHost;

    AmPluginInfo(String amHost, int amPluginPort,
        Token<JobTokenIdentifier> amPluginToken, String amPluginTokenJobId) {
      this.amHost = amHost;
      this.amPluginPort = amPluginPort;
      this.amPluginToken = amPluginToken;
      this.amPluginTokenJobId = amPluginTokenJobId;
    }
  }

  AmPluginInfo getAmPluginInfo(Ref<Integer> endpointVersion);
}

==> hive-apache-3.1.2-7-sources.jar: org/apache/hadoop/hive/ql/exec/tez/AmPluginNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.tez;

import org.apache.hadoop.security.token.Token;
import org.apache.hive.common.util.Ref;
import org.apache.tez.common.security.JobTokenIdentifier;
import io.trino.hive.$internal.org.codehaus.jackson.annotate.JsonIgnore;
import io.trino.hive.$internal.org.codehaus.jackson.annotate.JsonProperty;
import io.trino.hive.$internal.org.codehaus.jackson.map.annotate.JsonSerialize;

@JsonSerialize
public interface AmPluginNode {
  class AmPluginInfo {
    @JsonProperty("amPluginPort")
    public final int amPluginPort;
    public final Token<JobTokenIdentifier> amPluginToken;
    public final String amPluginTokenJobId;
    @JsonProperty("amHost")
    public final String amHost;

    AmPluginInfo(String amHost, int amPluginPort,
        Token<JobTokenIdentifier> amPluginToken, String amPluginTokenJobId) {
      this.amHost = amHost;
      this.amPluginPort = amPluginPort;
      this.amPluginToken = amPluginToken;
      this.amPluginTokenJobId = amPluginTokenJobId;
    }
  }

  AmPluginInfo getAmPluginInfo(Ref<Integer> endpointVersion);
}
